@@ -183,7 +183,7 @@ compareCols <- function(...,list.data,keep.names=TRUE,test.equal=FALSE,diff.only
 
             res.dims <- dims(list.data=dots)
             message("Dimensions:")
-            print(as.fun(res.dims))
+            message(print(as.fun(res.dims)))
         }
 
         if(nrow(dt.cols)==0&&ndots==1){
@@ -193,12 +193,12 @@ compareCols <- function(...,list.data,keep.names=TRUE,test.equal=FALSE,diff.only
         } else {
             if(diff.only){
                 message("\nColumns that differ:")
-                print(as.fun(dt.cols))
+                message(print(as.fun(dt.cols)))
                 message()
                 messageWrap(paste0("\nColumns where no differences were found: ",paste(dt.cols.full[nu==1&n==ndots,column],collapse=", "),"."),fun.msg=message)
             } else {
                 message("\nOverview of all columns:")
-                print(as.fun(dt.cols))
+                message(print(as.fun(dt.cols)))
             }
         }
         return(invisible(as.fun(dt.cols)))
