@@ -32,21 +32,24 @@ fix.time <- function(x,meta=T){
     x
 }
 
+quiet <- TRUE
 
 test_that("basic",{
     fileRef <- "testReference/NMcheckData_1.rds"
     
     pk <- readRDS(file="testData/data/xgxr2.rds")
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
 
     expect_equal_to_reference(res,fileRef,version=2)
 })
 
+
+
 test_that("No col.flagn",{
     fileRef <- "testReference/NMcheckData_2.rds"
     
     pk <- readRDS(file="testData/data/xgxr2.rds")
-    res <- NMcheckData(pk,col.flagn=FALSE, quiet=TRUE)
+    res <- NMcheckData(pk,col.flagn=FALSE, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 })
 
@@ -59,7 +62,7 @@ test_that("Misc findings",{
     ## a comma in a string - but with FLAG>0
     pk[2,ret.4:="3,mg"]
 
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
     
 })
@@ -73,7 +76,7 @@ test_that("TIME with characters",{
     pk[,TIME:=as.character(TIME)]
     pk[ROW==204,TIME:=paste0(TIME,"p")]
 
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
     
 })
@@ -90,7 +93,7 @@ test_that("Misc findings and dup colname",{
     colnames(pk)[22] <- "NAME"
     pk[2,ret.4:="3,mg"]
 
-    res <- expect_warning(NMcheckData(pk, quiet=TRUE))
+    res <- expect_warning(NMcheckData(pk, quiet=quiet))
     expect_equal_to_reference(res,fileRef,version=2)
     
 })
@@ -101,7 +104,7 @@ test_that("missing EVID",{
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk[,EVID:=NULL]
 
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
     
 })
@@ -112,7 +115,7 @@ test_that("missing ID",{
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk[,ID:=NULL]
 
-    expect_error( NMcheckData(pk, quiet=TRUE))
+    expect_error( NMcheckData(pk, quiet=quiet))
 })
 
 test_that("missing MDV",{
@@ -121,7 +124,7 @@ test_that("missing MDV",{
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk[,MDV:=1]
 
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
     ##         expect_equal(as.data.table(res)[level=="row"],as.data.table(readRDS(fileRef))[level=="row"])
 })
@@ -133,7 +136,7 @@ test_that("With ADDL, no II",{
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk[EVID==1,ADDL:=1]
 
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 })
 
@@ -144,7 +147,7 @@ test_that("With II, no ADDL",{
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk[EVID==1,II:=24]
 
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 })
 
@@ -166,7 +169,7 @@ test_that("ID and row with leading 0",{
     
     
     
-    res <- NMcheckData(pk, quiet=TRUE)
+    res <- NMcheckData(pk, quiet=quiet)
     ## res
     expect_equal_to_reference(res,fileRef,version=2)
 })
@@ -183,7 +186,7 @@ test_that("One covariate varying within ID",{
     pk <- readRDS(file="testData/data/xgxr2.rds")    
 
     pk[1500,WEIGHTB:=30]  
-    res <- NMcheckData(pk,covs=c("trtact","WEIGHTB","CYCLE","DOSE"), quiet=TRUE)
+    res <- NMcheckData(pk,covs=c("trtact","WEIGHTB","CYCLE","DOSE"), quiet=quiet)
     ## res
     expect_equal_to_reference(res,fileRef,version=2)
 })
@@ -204,7 +207,7 @@ test_that("with IOV",{
                  pk.fed)
     pk2[,ROW:=.I]
 
-    res <- NMcheckData(pk2,covs.occ=list(PERIOD=c("FED")),cols.num="REE", quiet=TRUE)
+    res <- NMcheckData(pk2,covs.occ=list(PERIOD=c("FED")),cols.num="REE", quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 
 })
@@ -221,7 +224,7 @@ test_that("covariates within subsets",{
     pk[EVID==1,ASSAY:=c(rep(NA,3),1,rep(NA,.N-4))]
 
     ## it finds way too many for ASSAY. Should only find 1.
-    res <- NMcheckData(pk,cols.num=list("EVID==0"=c("LLOQ","ASSAY"),"EVID==1"=c("site"),"WEIGHTB"), quiet=TRUE)
+    res <- NMcheckData(pk,cols.num=list("EVID==0"=c("LLOQ","ASSAY"),"EVID==1"=c("site"),"WEIGHTB"), quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 
 })
@@ -235,7 +238,7 @@ test_that("numerical coded as char and NA as .",{
     pk <- readRDS(file="testData/data/xgxr5.rds")
     
     ## it finds way too many for ASSAY. Should only find 1.
-    res <- NMcheckData(pk,na.strings=NULL, quiet=TRUE)
+    res <- NMcheckData(pk,na.strings=NULL, quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 
 })
@@ -249,7 +252,7 @@ test_that("usubjid OK",{
     pk[,usubjid:=paste0("100-",ID)]
     
     ## it finds way too many for ASSAY. Should only find 1.
-    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=TRUE)
+    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 
 
@@ -267,7 +270,7 @@ test_that("ID not unique",{
 
     
     ## it finds way too many for ASSAY. Should only find 1.
-    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=TRUE)
+    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 
 
@@ -286,7 +289,7 @@ test_that("usubjid not unique",{
 
     
     ## it finds way too many for ASSAY. Should only find 1.
-    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=TRUE)
+    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=quiet)
     expect_equal_to_reference(res,fileRef,version=2)
 })
 
@@ -295,10 +298,10 @@ test_that("no col.flagn",{
     
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk <- pk[FLAG==0]
-    res1 <- NMcheckData(pk, quiet=TRUE)
+    res1 <- NMcheckData(pk, quiet=quiet)
 
     pk[,FLAG:=NULL]
-    res2 <- NMcheckData(pk, quiet=TRUE)
+    res2 <- NMcheckData(pk, quiet=quiet)
     expect_equal(res1,res2)
 })
 
@@ -316,8 +319,8 @@ dups_data <- data.frame(
 
 
 test_that("check data files without cols.dup, but passed with it",{
-    no_dup_specified <- NMcheckData(dups_data, quiet=TRUE)
-    dup_specified <- NMcheckData(dups_data, cols.dup = "DVID", quiet=TRUE)
+    no_dup_specified <- NMcheckData(dups_data, quiet=quiet)
+    dup_specified <- NMcheckData(dups_data, cols.dup = "DVID", quiet=quiet)
     
     expect_equal(nrow(no_dup_specified), 2)
     expect_equal(nrow(dup_specified), 0)
@@ -332,7 +335,7 @@ test_that("simulation data",{
 
     dt.all <- rbind(dt.dos,dt.sim,fill=T)
     
-    res <- NMcheckData(dt.all, quiet=TRUE,type.data="sim")
+    res <- NMcheckData(dt.all, quiet=quiet,type.data="sim")
     ## nrow(res)
     expect_equal(nrow(res),0)
 
@@ -349,19 +352,30 @@ test_that("empty data set",{
     
     
     ## it finds way too many for ASSAY. Should only find 1.
-    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=TRUE)
+    res <- NMcheckData(pk,col.usubjid="usubjid", quiet=quiet)
 
     expect_equal_to_reference(res,fileRef)
 })
 
 
-test_that("basic",{
+test_that("disable column",{
     fileRef <- "testReference/NMcheckData_21.rds"
     
     pk <- readRDS(file="testData/data/xgxr2.rds")
     pk$CMT <- NULL
-    res <- NMcheckData(pk, quiet=TRUE,cols.disable="CMT")
+    res <- NMcheckData(pk, quiet=quiet,cols.disable="CMT")
 
     res
     expect_equal_to_reference(res,fileRef,version=2)
 })
+
+test_that("ID-level",{
+    fileRef <- "testReference/NMcheckData_22.rds"
+    
+    pk <- readRDS(file="testData/data/xgxr2.rds")
+    pk2 <- pk[TRTACT!="3 mg"]
+    pk3 <- pk2[!(ID<100&EVID==1)]
+    res <- NMcheckData(pk3, quiet=quiet)
+
+    expect_equal_to_reference(res,fileRef,version=2)
+})
